@@ -1,4 +1,5 @@
 ## BCEA-deprecated.R
+
 #' @title Deprecated functions in package \pkg{BCEA}.
 #' @description The functions listed below are deprecated and will be defunct in
 #'   the near future. When possible, alternative functions with similar
@@ -7,3 +8,11 @@
 #' @name BCEA-deprecated
 #' @keywords internal
 NULL
+
+#' @rdname BCEA-deprecated
+make.report <- function(...) {
+  .Deprecated(package = "BCEA",
+              msg = "'make.report()' is deprecated. Please use 'BCEAweb::make.report()' instead.")
+  
+  return(invisible(NULL))
+}
