@@ -1,9 +1,15 @@
 
-#
+#' Prepare contour plot parameters
+#' Additional to ceplane parameters
+#' @template args-he
+#' @param ... Additional parameters
+#' @return A list of parameters
+#' @keywords internal
+#' 
 prep_contour_params <- function(he, ...) {
   
   contour_params <- list(...)
-  ceplane_params <- prep_ceplane_params(he, wtp = 1e7, ...)
+  ceplane_params <- prep_ceplane_params(he, wtp_params = 1e7, ...)
   
   default_params <-
     modifyList(ceplane_params,
